<?php 

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_'))
	exit;
	
class Payanyway extends PaymentModule
{
    protected $_html = '';
    protected $_postErrors = array();

	public function __construct()
	{
		$this->name = 'payanyway';
		$this->tab = 'payments_gateways';
		$this->version = '2.2.1';
		$this->author = 'PayAnyWay';
        $this->controllers = array('validation');
        $this->bootstrap = true;
        $this->currencies = true;
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);

        parent::__construct();

		$this->displayName = 'PayAnyWay';
		$this->description = 'Receive payment with PayAnyWay';

        if (!count(Currency::checkPaymentCurrencies($this->id))) {
            $this->warning = 'No currency has been set for PayAnyWay.';
        }
	}

	/**
	 * create new order statuses
	 *
	 * @param $status
	 * @param $title
	 * @param $color
	 * @param $template
	 * @param $invoice
	 * @param $send_email
	 * @param $paid
	 * @param $logable
	 */
	public function createPayanywayPaymentStatus($status, $title, $color, $template, $invoice, $send_email, $paid, $logable)
	{
		$ow_status = Configuration::get($status);
		if ($ow_status === false)
		{
			$order_state = new OrderState();
			//$order_state->id_order_state = (int)$key;
		}
		else
			$order_state = new OrderState((int)$ow_status);

		$order_state->module_name = $this->name;

		$langs = Language::getLanguages();

		foreach ($langs as $lang)
			$order_state->name[$lang['id_lang']] = utf8_encode(html_entity_decode($title));

		$order_state->invoice = $invoice;
		$order_state->send_email = $send_email;

		if ($template != '')
			$order_state->template = $template;

		if ($paid != '')
			$order_state->paid = $paid;

		$order_state->logable = $logable;
		$order_state->color = $color;
		$order_state->save();

		Configuration::updateValue($status, (int)$order_state->id);

		copy(dirname(__FILE__).'/logo.gif', dirname(__FILE__).'/../../img/os/'.(int)$order_state->id.'.gif');
	}

	public function install()
	{
		if (!parent::install() || !$this->registerHook('paymentOptions'))
			return false;

		Configuration::updateValue('PAYANYWAY_PAYMENT_URL', 'www.payanyway.ru');
		Configuration::updateValue('PAYANYWAY_MNT_ID', '');
		Configuration::updateValue('PAYANYWAY_MNT_DATAINTEGRITY_CODE', '');
		Configuration::updateValue('PAYANYWAY_MNT_TEST_MODE', '0');

		$this->createPayanywayPaymentStatus('PAYANYWAY_OS_WAITING', 'Awaiting PayAnyWay payment', '#3333FF', 'payment_waiting', false, false, '', false);
		$this->createPayanywayPaymentStatus('PAYANYWAY_OS_SUCCEED', 'Accepted PayAnyWay payment', '#32cd32', 'payment', true, true, true, true);

		return true;
	}

    public function hookPaymentOptions($params)
    {
        global $cookie;

        if (!$this->active)
            return null;
        if (!$this->checkCurrency($params['cart']))
            return null;

        $embeddedOption = new PaymentOption();
        $embeddedOption
            ->setCallToActionText('PayAnyWay (VISA, MasterCard и более 30 других способов оплаты)')
            ->setAdditionalInformation($this->context->smarty->fetch('module:payanyway/views/templates/front/payment_infos.tpl'))
            ->setAction($this->context->link->getModuleLink($this->name, 'validation', array(), true))
            ->setLogo(Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/logo.png'));

        return array($embeddedOption);
    }

    public function checkCurrency($cart)
    {
        $currency_order = new Currency($cart->id_currency);
        $currencies_module = $this->getCurrency($cart->id_currency);

        if (is_array($currencies_module)) {
            foreach ($currencies_module as $currency_module) {
                if ($currency_order->id == $currency_module['id_currency']) {
                    return true;
                }
            }
        }
        return false;
    }

    public function uninstall()
    {
        Configuration::deleteByName('PAYANYWAY_PAYMENT_URL');
        Configuration::deleteByName('PAYANYWAY_MNT_ID');
        Configuration::deleteByName('PAYANYWAY_MNT_DATAINTEGRITY_CODE');
        Configuration::deleteByName('PAYANYWAY_MNT_TEST_MODE');

        return parent::uninstall();
    }

    public function getContent()
    {
        $this->_html = '<h2>'.$this->displayName.'</h2>';

        if (Tools::isSubmit('submitModule'))
        {
            Configuration::updateValue('PAYANYWAY_PAYMENT_URL', Tools::getvalue('payanyway_payment_url'));
            Configuration::updateValue('PAYANYWAY_MNT_ID', Tools::getvalue('payanyway_mnt_id'));
            Configuration::updateValue('PAYANYWAY_MNT_DATAINTEGRITY_CODE', Tools::getvalue('payanyway_mnt_dataintegrity_code'));
            Configuration::updateValue('PAYANYWAY_MNT_TEST_MODE', Tools::getvalue('payanyway_mnt_test_mode'));

            $this->_html .= $this->displayConfirmation($this->l('Configuration updated'));
        }

        $this->_html .= '
		<fieldset>
			<a href="http://www.payanyway.ru/" target="_blank"  style="float:left;margin-right:15px;"><img src="../modules/payanyway/payanyway.png" alt="PayAnyWay" /></a>
			<b>'.$this->l('This module allows you to accept payments with PayAnyWay.').'</b><br/><br/>
			<a target=\'_blank\' style=\'text-decoration:underline;\' href=\'https://payanyway.ru/info/w/ru/public/w/partnership/developers/instructions/prestashop17.html\'>'.$this->l('Follow instructions to configure PayAnyWay in Prestashop.').'</a>
			<br />
		</fieldset><br />
		<form action="'.Tools::htmlentitiesutf8($_SERVER['REQUEST_URI']).'" method="post">
			<fieldset>
				<legend><img src="../img/admin/contact.gif" alt="" />'.$this->l('Settings').'</legend>
				
				<label for="payanyway_payment_url">'.$this->l('Payment URL').'</label>
				<div class="margin-form">
				<select id="payanyway_payment_url" name="payanyway_payment_url">';
        $payment_urls = array('www.payanyway.ru', 'demo.moneta.ru');
        foreach ($payment_urls as $item)
        {
            $selected = (Configuration::get('PAYANYWAY_PAYMENT_URL') == $item) ? 'selected="selected"' : '';
            $this->_html .= '<option value="'.$item.'" '.$selected.'>'.$item.'</option>';
        }
        $this->_html .='
				</select>
				</div>
				
				<label for="payanyway_mnt_id">'.$this->l('Account number').'</label>
				<div class="margin-form"><input type="text" size="20" id="payanyway_mnt_id" name="payanyway_mnt_id" value="'.Configuration::get('PAYANYWAY_MNT_ID').'" /></div>
				
				<label for="payanyway_mnt_dataintegrity_code">'.$this->l('Data integrity code').'</label>
				<div class="margin-form"><input type="text" size="20" id="payanyway_mnt_dataintegrity_code" name="payanyway_mnt_dataintegrity_code" value="'.Configuration::get('PAYANYWAY_MNT_DATAINTEGRITY_CODE').'" /></div>
				
				<label for="payanyway_mnt_test_mode">'.$this->l('Mode').'</label>
				<div class="margin-form" id="payanyway_mnt_test">
					<input type="radio" name="payanyway_mnt_test_mode" value="0" style="vertical-align: middle;" '.(!Tools::getValue('payanyway_mnt_test_mode', Configuration::get('PAYANYWAY_MNT_TEST_MODE')) ? 'checked="checked"' : '').' />
					<span style="color: #080;">'.$this->l('Production').'</span>
					<input type="radio" name="payanyway_mnt_test_mode" value="1" style="vertical-align: middle;" '.(Tools::getValue('payanyway_mnt_test_mode', Configuration::get('PAYANYWAY_MNT_TEST_MODE')) ? 'checked="checked"' : '').' />
					<span style="color: #900;">'.$this->l('Test').'</span>
				</div>

				<br /><center><input type="submit" name="submitModule" value="'.$this->l('Update settings').'" class="button" /></center>
			</fieldset>
		</form>';

        return $this->_html;
    }

}

?>